@@ -1,29 +1,40 @@
 package resources
 
 import (
+	"context"
+
 	"github.com/aws/aws-sdk-go/aws"
-	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/globalaccelerator"
-	"github.com/rebuy-de/aws-nuke/v2/pkg/types"
+
+	"github.com/ekristen/libnuke/pkg/registry"
+	"github.com/ekristen/libnuke/pkg/resource"
+	"github.com/ekristen/libnuke/pkg/types"
+
+	"github.com/ekristen/aws-nuke/v3/pkg/nuke"
 )
 
-// GlobalAcceleratorListener model
-type GlobalAcceleratorListener struct {
-	svc *globalaccelerator.GlobalAccelerator
-	ARN *string
-}
+const GlobalAcceleratorListenerResource = "GlobalAcceleratorListener"
 
 func init() {
-	register("GlobalAcceleratorListener", ListGlobalAcceleratorListeners)
+	registry.Register(&registry.Registration{
+		Name:     GlobalAcceleratorListenerResource,
+		Scope:    nuke.Account,
+		Resource: &GlobalAcceleratorListener{},
+		Lister:   &GlobalAcceleratorListenerLister{},
+	})
 }
 
-// ListGlobalAcceleratorListeners enumerates all available listeners of all available accelerators
-func ListGlobalAcceleratorListeners(sess *session.Session) ([]Resource, error) {
-	svc := globalaccelerator.New(sess)
-	acceleratorARNs := []*string{}
-	resources := []Resource{}
+type GlobalAcceleratorListenerLister struct{}
 
-	// get all accelerator arns
+// List enumerates all available listeners of all available accelerators
+func (l *GlobalAcceleratorListenerLister) List(_ context.Context, o interface{}) ([]resource.Resource, error) {
+	opts := o.(*nuke.ListerOpts)
+
+	svc := globalaccelerator.New(opts.Session)
+	var acceleratorARNs []*string
+	resources := make([]resource.Resource, 0)
+
+	// get all accelerator ARNs
 	acceleratorParams := &globalaccelerator.ListAcceleratorsInput{
 		MaxResults: aws.Int64(100),
 	}
@@ -45,7 +56,7 @@ func ListGlobalAcceleratorListeners(sess *session.Session) ([]Resource, error) {
 		acceleratorParams.NextToken = output.NextToken
 	}
 
-	// get all listerners
+	// get all listeners
 	for _, acceleratorARN := range acceleratorARNs {
 		params := &globalaccelerator.ListListenersInput{
 			MaxResults:     aws.Int64(100),
@@ -76,23 +87,29 @@ func ListGlobalAcceleratorListeners(sess *session.Session) ([]Resource, error) {
 	return resources, nil
 }
 
+// GlobalAcceleratorListener model
+type GlobalAcceleratorListener struct {
+	svc *globalaccelerator.GlobalAccelerator
+	ARN *string
+}
+
 // Remove resource
-func (gal *GlobalAcceleratorListener) Remove() error {
-	_, err := gal.svc.DeleteListener(&globalaccelerator.DeleteListenerInput{
-		ListenerArn: gal.ARN,
+func (g *GlobalAcceleratorListener) Remove(_ context.Context) error {
+	_, err := g.svc.DeleteListener(&globalaccelerator.DeleteListenerInput{
+		ListenerArn: g.ARN,
 	})
 
 	return err
 }
 
 // Properties definition
-func (gal *GlobalAcceleratorListener) Properties() types.Properties {
+func (g *GlobalAcceleratorListener) Properties() types.Properties {
 	properties := types.NewProperties()
-	properties.Set("ARN", gal.ARN)
+	properties.Set("ARN", g.ARN)
 	return properties
 }
 
 // String representation
-func (gal *GlobalAcceleratorListener) String() string {
-	return *gal.ARN
+func (g *GlobalAcceleratorListener) String() string {
+	return *g.ARN
 }
